@@ -5,7 +5,9 @@ module Jekyll
     module Hook
       def self.add_determinator_proc
         proc { |item|
-          item.data['last_modified_at'] = Determinator.new(item.site.source, item.path)
+          format = item.site.config.dig('last-modified-at', 'date-format')
+          item.data['last_modified_at'] = Determinator.new(item.site.source, item.path,
+                                                           format)
         }
       end
 
